@@ -8,7 +8,7 @@ from w3lib.url import url_query_cleaner
 __author__ = "Elton H.Y. Chou"
 
 __license__ = "MIT"
-__version__ = "0.0.2-beta"
+__version__ = "0.0.3-beta"
 __maintainer__ = "Elton H.Y. Chou"
 __email__ = "plscd748@gmail.com"
 
@@ -24,10 +24,12 @@ class NoMoreQS:
         Parameters
         ----------
         include_flds : Union[List[str], Tuple[str]], optional
-            first-level domains list which are allowed to clean query string., by default []
+            first-level domains list which are allowed to clean query string,
+            by default []
 
         exclude_flds : Union[List[str], Tuple[str]], optional
-            first-level domains which are disallowed to clean query string., by default []
+            first-level domains which are disallowed to clean query string,
+            by default []
 
         strict : bool, optional
             mode of clean, by default True
@@ -117,14 +119,14 @@ def _super_cleaner(url: str, allow_og_url: bool = False, **kwargs):
 
     page = BeautifulSoup(response.text, "lxml")
 
-    canonical_url = _get_canonical_url(page)
-    if canonical_url:
-        return canonical_url
-
     if allow_og_url:
         og_url = _get_og_url(page)
         if og_url:
-            return og_url
+            return _fbclid_cleaner(og_url)
+
+    canonical_url = _get_canonical_url(page)
+    if canonical_url:
+        return _fbclid_cleaner(canonical_url)
 
     return _fbclid_cleaner(url)
 
@@ -162,9 +164,7 @@ def _get_canonical_url(page: BeautifulSoup) -> str:
         link[canonical url]
     """
     canonical_url = page.select_one("link[rel='canonical']")
-    if canonical_url:
-        return canonical_url["href"]
-    return ''
+    return canonical_url["href"] if canonical_url else ''
 
 
 def _get_og_url(page: BeautifulSoup) -> str:
@@ -182,6 +182,4 @@ def _get_og_url(page: BeautifulSoup) -> str:
         meta[og:url]
     """
     og_url = page.select_one("meta[property='og:url']")
-    if og_url:
-        return og_url["content"]
-    return ''
+    return og_url["content"] if og_url else ''
